use serde::Serialize;
use wasm_bindgen::{prelude::wasm_bindgen, JsError, JsValue};

use crate::schemes::q_style::ColorShifting;

#[derive(Debug, Clone, Serialize)]
#[wasm_bindgen]
pub struct SwatchSchemeSetting {
    pub amount: usize,
    pub min_lightness: f32,
    pub max_lightness: f32,
    pub include_primary: bool,
    pub dark_convert: ColorShifting,
}

impl Default for SwatchSchemeSetting {
    fn default() -> Self {
        Self {
            amount: 10,
            min_lightness: 10.0,
            max_lightness: 90.0,
            include_primary: false,
            dark_convert: ColorShifting {
                chroma: -0.3,
                lightness: -0.3,
            },
        }
    }
}

#[wasm_bindgen]
impl SwatchSchemeSetting {
    #[wasm_bindgen(constructor)]
    pub fn new(
        amount: usize,
        min_lightness: f32,
        max_lightness: f32,
        include_primary: bool,
        dark_convert: ColorShifting,
    ) -> Self {
        Self {
            amount,
            min_lightness,
            max_lightness,
            include_primary,
            dark_convert,
        }
    }

    #[wasm_bindgen(js_name = toJsValue)]
    pub fn to_js_value(&self) -> Result<JsValue, JsError> {
        Ok(serde_wasm_bindgen::to_value(self)?)
    }
}
